#
# spec file for package container-suseconnect
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global project     container-suseconnect
%global import_path github.com/SUSE/%{project}
%global zypp_path   %{_prefix}/lib/zypp/plugins
%global zypp_services %{zypp_path}/services
%global zypp_urlresolver %{zypp_path}/urlresolver
Name:           %{project}
Version:        2.4.0
Release:        150000.4.50.2
Summary:        Provides access to repositories inside containers
License:        Apache-2.0
Group:          Development/Languages/Other
URL:            https://%{import_path}
Source0:        %{project}-%{version}.tar.zst
Source1:        vendor.tar.zst
Source2:        container-suseconnect-rpmlintrc
BuildRequires:  golang-packaging
BuildRequires:  zstd
BuildRequires:  libzypp > 9.34
Requires:       libzypp > 9.34
%{go_provides}
%{go_exclusivearch}

%description
container-suseconnect gives access to package repositories inside containers
using the host machine entitlements.

%prep
%setup -q -n %{project}-%{version} -a1

%build
%{goprep} %{import_path}
%{gobuild} cmd/container-suseconnect

%install
%{goinstall}
%{gofilelist}
mkdir -p %{buildroot}/%{zypp_services}
mkdir -p %{buildroot}/%{zypp_urlresolver}
ln -s %{_bindir}/%{project} %{buildroot}/%{zypp_services}/%{project}-zypp
ln -s %{_bindir}/%{project} %{buildroot}/%{zypp_urlresolver}/susecloud

%files -f file.lst
%doc README.md
%license LICENSE
%{_bindir}/%{project}
%{zypp_services}/%{project}-zypp
%{zypp_urlresolver}/susecloud

%changelog
* Tue Dec  6 2022 dmueller@suse.com
- update to 2.4.0 (jsc#PED-1710):
  * Fix docker build example for non-SLE hosts
  * Minor fixes to --help and README
  * Improve documentation when building with podman on non-SLE host
  * Add flag --log-credentials-errors
  * Add GitHub actions
  * Remove vendor/ dir
  * Cleanup tests
  * Update capture to the 1.0.0 release
  * Bump cli to 2.34.4
  * Update cli to 2.23.5
  * Add dependabot
  * Use URL.Redacted() to avoid security scanner warning
  * Regcode fix
* Sat Mar 27 2021 dmueller@suse.com
- strip binaries (removes 4MB/25%% of the uncompressed size) (bsc#1186827)
* Tue Jun 30 2020 rhafer@suse.com
- Update to 2.3.0 (bsc#1173375)
  - Introduce "containerbuild-regionsrv" support and add
    "susecloud" zypper url-resolver plugin to allow building SLE
    containers on public cloud on-demand instances
  - Fix usage with RMT when repositories require authentication
- remove "%%gosrc" call to avoid including all the go sources into
  the main package.
* Thu Nov 28 2019 rhafer@suse.com
- Update to 2.2.0 (bsc#1157960)
  - Update go version and dependencies
  - Fix usage with RMT and SMT
  - parse the /etc/products.d/*.prod files
* Wed Jun 19 2019 sgrunert@suse.com
- Update to 2.1.0 (bsc#1138731, bsc#1154247)
  - Fix function comments based on best practices from Effective Go
  - Interacting with SCC behind proxy and SMT
* Tue Dec 11 2018 sgrunert@suse.com
- Update to 2.0.0 (bsc#1119496)
  - Add command line interface
  - Add `ADDITIONAL_MODULES` capability to enable further extension
    modules during image build and run
  - Add documentation about how to build docker images on non SLE
    distributions
  - Improve documentation to clarify how container-suseconnect
    works in a Dockerfile
  - Improve error handling on non SLE hosts
  - Fix bug which makes container-suseconnect work on SLE15 based
    distributions
- Update build to use latest golang-packaging
- Added container-suseconnect-rpmlintrc
* Thu Mar  1 2018 jmassaguerpla@suse.com
- Remove gcc since the latest go versions already support s390x, ppc64le
  Remove 0001-Added-TLS-root-CA-certificates-for-SLE-11.patch: this
  was needed for gcc builds. (fix bsc#1083189)
* Wed Jul 27 2016 cbrauner@suse.de
- add aarch64 to supported gc architectures
* Wed Nov 11 2015 fcastelli@suse.com
- Update to version 1.1.0:
  - Improve logging
* Wed Nov 11 2015 fcastelli@suse.com
- Added 0001-Added-TLS-root-CA-certificates-for-SLE-11.patch to handle
  SLE11 certificates on non-x86 architectures
  work-around for bsc#953831
* Mon Jul 20 2015 fcastelli@suse.com
- Build using gcc on platforms where gc compiler is not available
* Thu Jun 18 2015 jmassaguerpla@suse.com
- Make SUSEConnect configuration file optional
  Update to v1.0.1
* Tue Jun 16 2015 jmassaguerpla@suse.com
- Update to v1.0.0
* Thu Jun 11 2015 fcastelli@suse.com
- Update to latest version from git
* Thu Jun  4 2015 fcastelli@suse.com
- Fixed building
* Thu Jun  4 2015 fcastelli@suse.com
- Update to latest version of container-suseconnect
* Wed Jun  3 2015 fcastelli@suse.com
- Fix libzypp requirement, it must be a runtime one
* Wed Jun  3 2015 fcastelli@suse.com
- Relax libzypp requirement to build the package also on SLE11SP3
* Fri May 29 2015 dmacvicar@suse.de
- initial package
